%define enable_atlas 0
%{?_with_atlas: %global enable_atlas 1}

%define module	numpy
%define name	python-%{module}
%define epoch 	1

# disable this for bootstrapping nose and sphinx
# there is no python3-nose yet
%define enable_tests 0
%define enable_doc 0


Summary:	A fast multidimensional array facility for Python
Name:		python-%{module}
Version:	1.8.2
Epoch:		%{epoch}
Release:	%mkrel 4
License:	BSD
Group:		Development/Python
Url: 		http://numpy.scipy.org
Source0:	http://downloads.sourceforge.net/numpy/%{module}-%{version}.tar.gz
Provides:	f2py
Obsoletes:	f2py
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif
BuildRequires:	lapack-devel
BuildRequires:	gcc-gfortran >= 4.0
%if %enable_doc
BuildRequires:	python-sphinx >= 1.0
BuildRequires:	python-matplotlib
%endif
%if %enable_tests
BuildRequires:	python-nose
%endif
BuildRequires:	pkgconfig(python)
BuildRequires:	python-cython
BuildRequires:	python-setuptools
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools

Obsoletes:	python-numeric < 24.2-8
Provides:	python-numeric

%description
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package devel
Summary:	Numpy headers
Group:		Development/Python
Requires:	%{name} = %{epoch}:%{version}-%{release}
Obsoletes:  python-numeric-devel < 2.8
Provides:   python-numeric-devel = %epoch:%version-%release

%description devel
This package contains header files need to develop modules 
in C and Fortran that can interact with Numpy

%package -n python3-numpy
Summary:    A fast multidimensional array facility for Python3
Group:		Development/Python
License:    BSD

%description -n python3-numpy
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-numpy-devel
Summary:    Numpy headers
Group:		Development/Python
Requires:   python3-numpy = %{epoch}:%{version}-%{release}
Obsoletes:  python3-numeric-devel < 2.8
Provides:   python3-numeric-devel = %epoch:%version-%release

%description -n python3-numpy-devel
This package contains header files need to develop modules 
in C and Fortran that can interact with Numpy

%prep
%setup -q -n %{module}-%{version}
# workaround for rhbz#849713
# http://mail.scipy.org/pipermail/numpy-discussion/2012-July/063530.html
rm numpy/distutils/command/__init__.py && touch numpy/distutils/command/__init__.py

cp -a . %{py3dir}

%build
pushd %{py3dir}
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py build
popd

#CFLAGS="%{optflags} -fPIC -O3" PYTHONDONTWRITEBYTECODE= %{__python} setup.py config_fc --fcompiler=gnu95 build
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python} setup.py build

%if %enable_doc
pushd doc
export PYTHONPATH=`dir -d ../build/lib.linux*`
%make html
popd
%endif

%install
# first install python3 so the binaries are overwritten by the python2 ones
pushd %{py3dir}
#%{__python} setup.py install -O1 --skip-build --root %{buildroot}
# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py install --root %{buildroot}
%__rm -rf docs-f2py ; mv %{buildroot}%{python3_sitearch}/%{module}/f2py/docs docs-f2py
%__mv -f %{buildroot}%{python3_sitearch}/%{module}/f2py/f2py.1 f2py.1
%__rm -rf doc ; mv -f %{buildroot}%{python3_sitearch}/%{module}/doc .
install -D -p -m 0644 f2py.1 %{buildroot}%{_mandir}/man1/f2py.1
pushd %{buildroot}%{_bindir} &> /dev/null
popd &> /dev/null

# Remove doc files. They should in in %doc
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/COMPATIBILITY
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/DEV_README.txt
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/INSTALL.txt
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/LICENSE.txt
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/README.txt
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/THANKS.txt
%__rm -f %{buildroot}%{python3_sitearch}/%{module}/site.cfg.example

popd
# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python} setup.py install --root %{buildroot}

%__rm -rf docs-f2py; %__mv %{buildroot}%{py_platsitedir}/%{module}/f2py/docs docs-f2py
%__mv -f %{buildroot}%{py_platsitedir}/%{module}/f2py/f2py.1 f2py.1
%__install -D -p -m 0644 f2py.1 %{buildroot}%{_mandir}/man1/f2py.1

%__rm -rf %{buildroot}%{py_platsitedir}/%{module}/tools/

# Remove doc files that should be in %doc:
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/COMPATIBILITY
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/*.txt
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/site.cfg.example

%check
%if %enable_tests

# Don't run tests from within main directory to avoid importing the uninstalled numpy stuff:
pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{py_platsitedir}" %{__python} -c "import pkg_resources, numpy; numpy.test()"
popd &> /dev/null

pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{python3_sitearch}" %{__python3} -c "import pkg_resources, numpy ; numpy.test()"
popd &> /dev/null
%endif

%files 
%doc LICENSE.txt README.txt THANKS.txt DEV_README.txt COMPATIBILITY site.cfg.example 
%if %enable_doc
%doc doc/build/html
%endif
%dir %{python_sitearch}/%{module}
%{python_sitearch}/%{module}/*.py*
%{python_sitearch}/%{module}/core/ 
%{python_sitearch}/%{module}/compat/
%{python_sitearch}/%{module}/doc/
%exclude %{python_sitearch}/%{module}/core/include/
%{python_sitearch}/%{module}/fft/
%{python_sitearch}/%{module}/lib/
%{python_sitearch}/%{module}/linalg/
%{python_sitearch}/%{module}/ma/
%{python_sitearch}/%{module}/matrixlib/
%{python_sitearch}/%{module}/numarray/
%exclude %{python_sitearch}/%{module}/numarray/include/
%{python_sitearch}/%{module}/oldnumeric/
%{python_sitearch}/%{module}/polynomial/
%{python_sitearch}/%{module}/random/
%exclude %{python_sitearch}/%{module}/random/randomkit.h
%{python_sitearch}/%{module}/testing/
%{python_sitearch}/%{module}/tests/ 
%{python_sitearch}/%{module}-*.egg-info
%{python_sitearch}/%{module}/distutils/
%{python_sitearch}/%{module}/f2py/
%{_bindir}/f2py
%{_mandir}/man1/f2py.*

%files devel
%{python_sitearch}/%{module}/core/include/
%{python_sitearch}/%{module}/numarray/include/
%{python_sitearch}/%{module}/random/randomkit.h

%files -n python3-numpy
%doc LICENSE.txt README.txt THANKS.txt DEV_README.txt COMPATIBILITY site.cfg.example
%{python3_sitearch}/%{module}/__pycache__/*
%dir %{python3_sitearch}/%{module}
%{python3_sitearch}/%{module}/*.py*
%{python3_sitearch}/%{module}/core
%{python3_sitearch}/%{module}/distutils
%{python3_sitearch}/%{module}/fft
%{python3_sitearch}/%{module}/lib
%{python3_sitearch}/%{module}/linalg
%{python3_sitearch}/%{module}/ma
%{python3_sitearch}/%{module}/numarray
%{python3_sitearch}/%{module}/oldnumeric
%{python3_sitearch}/%{module}/random
%{python3_sitearch}/%{module}/testing
%{python3_sitearch}/%{module}/tests
%{python3_sitearch}/%{module}/compat
%{python3_sitearch}/%{module}/matrixlib
%{python3_sitearch}/%{module}/polynomial
%{python3_sitearch}/%{module}-*.egg-info
%{_bindir}/f2py3
%{python3_sitearch}/%{module}/f2py
%exclude %{python3_sitearch}/%{module}/core/include/
%exclude %{python3_sitearch}/%{module}/numarray/include/
%exclude %{python3_sitearch}/%{module}/random/randomkit.h

%files -n python3-numpy-devel
%{python3_sitearch}/%{module}/core/include/
%{python3_sitearch}/%{module}/numarray/include/
%{python3_sitearch}/%{module}/random/randomkit.h



%changelog
* Wed Oct 15 2014 umeabot <umeabot> 1:1.8.2-4.mga5
+ Revision: 749676
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:1.8.2-3.mga5
+ Revision: 726911
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:1.8.2-2.mga5
+ Revision: 688185
- Mageia 5 Mass Rebuild

* Fri Aug 15 2014 philippem <philippem> 1:1.8.2-1.mga5
+ Revision: 662701
- update to 1.8.2

* Sat May 31 2014 pterjan <pterjan> 1:1.8.1-3.mga5
+ Revision: 628852
- Rebuild for new Python

* Wed Apr 09 2014 philippem <philippem> 1:1.8.1-2.mga5
+ Revision: 613118
- move f2py and distutils into main package, let only headers in devel packages

* Sun Mar 30 2014 philippem <philippem> 1:1.8.1-1.mga5
+ Revision: 610377
- update to 1.8.1

* Wed Feb 19 2014 philippem <philippem> 1:1.8.0-2.mga5
+ Revision: 594840
- Fix CVE-2014-1858, CVE-2014-1859 (mga#12814)

* Fri Dec 27 2013 philippem <philippem> 1:1.8.0-1.mga4
+ Revision: 560969
- Update to 1.8.0

* Tue Oct 22 2013 umeabot <umeabot> 1:1.7.1-3.mga4
+ Revision: 543984
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1:1.7.1-2.mga4
+ Revision: 498975
- Rebuild to add different pythonegg provides for python 2 and 3

  + philippem <philippem>
    - cleaning spec

* Thu Jun 27 2013 philippem <philippem> 1:1.7.1-1.mga4
+ Revision: 447337
- new upstream
- Python 3 package

* Sun Jan 13 2013 umeabot <umeabot> 1:1.6.2-2.mga3
+ Revision: 379178
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 08 2012 philippem <philippem> 1:1.6.2-1.mga3
+ Revision: 290081
- New upstream release 1.6.2

* Fri Sep 16 2011 philippem <philippem> 1:1.6.1-2.mga2
+ Revision: 144223
-update to new upstream

* Mon Jul 04 2011 ahmad <ahmad> 1:1.6.0-1.mga2
+ Revision: 118035
- Update to 1.6.0

* Tue May 03 2011 ahmad <ahmad> 1:1.5.1-5.mga1
+ Revision: 94531
- Fix python-numeric obosletes
- Make the python-numeric Provides generic

* Fri Apr 29 2011 dmorgan <dmorgan> 1:1.5.1-4.mga1
+ Revision: 93481
- Obsoletes/Provides python-numeric

* Mon Jan 17 2011 pterjan <pterjan> 1:1.5.1-3.mga1
+ Revision: 20951
- Fix extensiosn linkage

  + misc <misc>
    - use a hack to make it compile until we can properly debug this
      ( ie, after the bootstrap phase )

  + ahmad <ahmad>
    - rebuild for python-2.7

* Thu Jan 13 2011 ahmad <ahmad> 1:1.5.1-2.mga1
+ Revision: 8284
- drop %%py_requires macro and use BR python-devel
- imported package python-numpy


* Thu Nov 18 2010 Lev Givon <lev@mandriva.org> 1:1.5.1-1mdv2011.0
+ Revision: 598753
- Update to 1.5.1.

* Sat Oct 30 2010 Götz Waschk <waschk@mandriva.org> 1:1.5.0-5mdv2011.0
+ Revision: 590554
- rebuild for new python

* Sat Oct 30 2010 Olivier Thauvin <nanardon@mandriva.org> 1:1.5.0-4mdv2011.0
+ Revision: 590528
- rebuild

  + Michael Scherer <misc@mandriva.org>
    - add a switch to disable doc due to boostraping problem
    - disable test, so we can recompile for python 2.7
    - rebuild for python 2.7

* Thu Sep 16 2010 Lev Givon <lev@mandriva.org> 1:1.5.0-2mdv2011.0
+ Revision: 578796
- Patch to enable doc build (numpy bug #1596).

* Tue Aug 31 2010 Lev Givon <lev@mandriva.org> 1:1.5.0-1mdv2011.0
+ Revision: 574837
- Update to 1.5.0.

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - don't manually compress package in %%install, it breaks short-circuitting and
      is also automatically done by helpers anyways..

* Tue Apr 27 2010 Christophe Fergeau <cfergeau@mandriva.com> 1:1.4.1-2mdv2010.1
+ Revision: 539595
- rebuild so that shared libraries are properly stripped again

* Thu Apr 22 2010 Lev Givon <lev@mandriva.org> 1:1.4.1-1mdv2010.1
+ Revision: 537982
- Update to 1.4.1.

* Thu Jan 28 2010 Frederik Himpe <fhimpe@mandriva.org> 1:1.4.0-1mdv2010.1
+ Revision: 497771
- Disable atlas build: it is not in main

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - new version

  + Lev Givon <lev@mandriva.org>
    - Clean up spec file.
      Build against atlas instead of netlib blas/lapack.

* Thu Sep 10 2009 Lev Givon <lev@mandriva.org> 1:1.3.0-4mdv2010.0
+ Revision: 436957
- Remove python-devel suggested install because it induces
  installation of lots of other devel stuff.

* Tue Sep 08 2009 Lev Givon <lev@mandriva.org> 1:1.3.0-3mdv2010.0
+ Revision: 433755
- Add python-devel as a suggested install because it is required to run
  some tests.

* Wed Sep 02 2009 Lev Givon <lev@mandriva.org> 1:1.3.0-2mdv2010.0
+ Revision: 424322
- Add python-nose as an optional install dependency.

* Fri Jun 19 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:1.3.0-1mdv2010.0
+ Revision: 387249
- boost gcc optimization level to -O3 as this proves beneficial for performance

* Sun Apr 05 2009 Lev Givon <lev@mandriva.org> 1:1.3.0-1mdv2009.1
+ Revision: 364159
- Update to 1.3.0.

* Thu Mar 19 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.3.0b1-1mdv2009.1
+ Revision: 358059
- Update to latest upstream release.

* Thu Dec 25 2008 Adam Williamson <awilliamson@mandriva.org> 1.2.1-3mdv2009.1
+ Revision: 318550
- rebuild for new python

* Tue Nov 25 2008 Lev Givon <lev@mandriva.org> 1.2.1-2mdv2009.1
+ Revision: 306745
- Rebuild against lapack 3.2.

* Thu Oct 30 2008 Lev Givon <lev@mandriva.org> 1.2.1-1mdv2009.1
+ Revision: 298753
- Update to 1.2.1.

* Sun Oct 26 2008 Lev Givon <lev@mandriva.org> 1.2.0-1mdv2009.1
+ Revision: 297454
- Update to 1.2.0.

* Sun Aug 03 2008 Lev Givon <lev@mandriva.org> 1.1.1-1mdv2009.0
+ Revision: 262015
- Update to 1.1.1.

* Fri Jul 11 2008 Lev Givon <lev@mandriva.org> 1.1.0-2mdv2009.0
+ Revision: 233799
- Bump release to rebuild against reorganized blas/lapack libraries.

* Thu May 29 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.0-1mdv2009.0
+ Revision: 212881
- update to new version 1.1.0
- spec file clean

  + Thierry Vignaud <tv@mandriva.org>
    - fix summary-not-capitalized
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Nov 13 2007 Lev Givon <lev@mandriva.org> 1.0.4-1mdv2008.1
+ Revision: 108503
- Update to 1.0.4.

* Fri Nov 09 2007 Lev Givon <lev@mandriva.org> 1.0.3.1-2mdv2008.1
+ Revision: 106991
- Bump release to rebuild against lapack 3.1.1.

* Wed Aug 22 2007 Lev Givon <lev@mandriva.org> 1.0.3.1-1mdv2008.0
+ Revision: 69185
- Update to 1.0.3.1.

* Wed Jun 20 2007 Lev Givon <lev@mandriva.org> 1.0.3-1mdv2008.0
+ Revision: 41659
- Update to 1.0.3.

* Tue Apr 17 2007 Lev Givon <lev@mandriva.org> 1.0.2-1mdv2008.0
+ Revision: 13991
- Update to 1.0.2.


* Mon Jan 22 2007 Lev Givon <lev@mandriva.org> 1.0.1-2mdv2007.0
+ Revision: 111955
- Patch to search for X11 libs in lib64 (Bug 28348).

* Sat Dec 02 2006 Emmanuel Andry <eandry@mandriva.org> 1.0.1-1mdv2007.1
+ Revision: 90060
- new version 1.0.1

* Thu Oct 26 2006 Lev Givon <lev@mandriva.org> 1.0rc1-1mdv2007.1
+ Revision: 72558
- Import python-numpy

* Wed Sep 27 2006 Lev Givon <lev@mandriva.org> 1.0rc1-1mdk
- Update.

* Mon Jul 31 2006 Lev Givon <lev@mandriva.org> 1.0b1-1mdk
- Update.

* Tue May 23 2006 Lev Givon <lev@mandriva.org> 0.9.8-2mdk
- Put all .h files in devel package.

* Fri May 19 2006 Lev Givon <lev@mandriva.org> 0.9.8-1mdk
- Update.

* Tue Apr 25 2006 Lev Givon <lev@mandriva.org> 0.9.6-2mdk
- Fix build dependencies.

* Sun Mar 19 2006 Lev Givon <lev@mandriva.org> 0.9.6-1mdk
- Update.

* Fri Mar 17 2006 Lev Givon <lev@mandriva.org> 0.9.5-4mdk
- Make package obsolete old f2py.

* Thu Mar 16 2006 Lev Givon <lev@mandriva.org> 0.9.5-3mdk
- Fix multiarch problem.

* Thu Mar 02 2006 Lev Givon <lev@mandriva.org> 0.9.5-2mdk
- Define devel package.

* Thu Feb 23 2006 Lev Givon <lev@mandriva.org> 0.9.5-1mdk
- Update.

* Tue Jan 31 2006 Lev Givon <lev@mandriva.org> 0.9.4-1mdk
- Update.

* Fri Jan 20 2006 Lev Givon <lev@mandriva.org> 0.9.2-1mdk
- Initial Mandriva package.

